/**
 * Concrete class that computes exponentiation by repeated squaring.
 *
 * @author Tom Verhoeff (TU/e)
 */
public class PowerByRepeatedSquaring extends AbstractPowerClass {

    @Override
    public long power(int a, int b) {
        if (b < 0) {
            throw new IllegalArgumentException("power: negative exponent");
        }
        // 0 <= b
        long x = a; // see invariant
        int k = b; // see invariant
        long result = 1; // see invariant
        // invariant: 0 <= k <= b && result * x^k == a^b
        while (k != 0) {
            if (k % 2 == 0) { // even exponent
                x *= x;
                k /= 2;
            } else { // odd exponent
                result *= x;
                k -= 1;
            }
            // invariant holds again, k has decreased
        }
        // k == 0, hence result == a^b
        return result;
    }

}
