import static org.junit.Assert.*;
import org.junit.Test;

/**
 * Test cases for SimpleClass.
 *
 * @author Tom Verhoeff (TU/e)
 */
public class SimpleClassTest {

    public SimpleClassTest() {
    }

    /**
     * Test of divide method, of class SimpleClass.
     * Typical values, without remainder.
     */
    @Test
    public void divisionWithoutRemainder() {
        System.out.println("divide, without remainder");
        int a = 12;
        int b = 3;
        SimpleClass instance = new SimpleClass();
        int expResult = 4;
        int result = instance.divide(a, b);
        assertEquals("result", expResult, result);
    }

    /**
     * Test of divide method, of class SimpleClass.
     * Typical values, with remainder.
     */
    @Test
    public void divisionWithRemainder() {
        System.out.println("divide, with remainder");
        int a = 14;
        int b = 3;
        SimpleClass instance = new SimpleClass();
        int expResult = 4;
        int result = instance.divide(a, b);
        assertEquals(expResult, result);
    }

    /**
     * Test of divide method, of class SimpleClass.
     * Division by zero needs to throw exception;
     * simplest version.
     */
    @Test(expected = IllegalArgumentException.class)
    public void divisionByZero() {
        System.out.println("divide, by zero");
        int a = 6;
        int b = 0;
        SimpleClass instance = new SimpleClass();
        instance.divide(a, b);
    }

    /**
     * Test of divide method, of class SimpleClass.
     * Division by zero needs to throw exception;
     * also check that message is not null.
     */
    @Test
    public void divisionByZeroBetter() {
        System.out.println("divide, by zero (better)");
        Class expected = IllegalArgumentException.class;
        int a = 6;
        int b = 0;
        SimpleClass instance = new SimpleClass();
        try {
            instance.divide(a, b);
            fail("should have thrown " + expected);
        } catch (Exception e) {
            assertTrue("type: " + e.getClass().getName()
                    + " should be instance of " + expected,
                    expected.isInstance(e));
            assertNotNull("message should not be null",
                    e.getMessage());
        }
    }

}
